@@ -9,7 +9,7 @@ purkada.pred <- function(ynew, y, ina) {
   mat <- matrix(0, dim(ynew)[1], g)
   for (j in 1:g) {
     mod <- Directional::purka.mle( y[ina == j, ] )
-    mat[, j] <- Directional::dpurka(ynew, mod$alpha, mod$theta, logden = TRUE )
+    mat[, j] <- Directional::dpurka(ynew, mod$theta, mod$alpha, logden = TRUE )
   }
   Rfast::rowMaxs(mat)
 }
